emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/bug-hunter 6c56fc3 80/95: Fix frame -> instance


From: Stefan Monnier
Subject: [elpa] externals/bug-hunter 6c56fc3 80/95: Fix frame -> instance
Date: Fri, 27 Nov 2020 22:07:01 -0500 (EST)

branch: externals/bug-hunter
commit 6c56fc3f1f822b067323ed5fce900a8bb1ff6019
Author: Artur Malabarba <bruce.connor.am@gmail.com>
Commit: Artur Malabarba <bruce.connor.am@gmail.com>

    Fix frame -> instance
---
 README.org    | 4 ++--
 bug-hunter.el | 8 ++++----
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/README.org b/README.org
index ace7463..78c622e 100644
--- a/README.org
+++ b/README.org
@@ -26,8 +26,8 @@ should, invoke the same command, but choose the interactive 
option:
 #+BEGIN_SRC text
 M-x bug-hunter-init-file RET i
 #+END_SRC
-The Bug Hunter will start a separate Emacs frame several times, and
-then it will ask you each time whether that frame presented the
+The Bug Hunter will start a separate Emacs instance several times, and
+then it will ask you each time whether that instance presented the
 problem you have. After doing this about 5--12 times, you’ll be given
 the results.
 
diff --git a/bug-hunter.el b/bug-hunter.el
index 9cdb4f6..cf35edc 100644
--- a/bug-hunter.el
+++ b/bug-hunter.el
@@ -49,8 +49,8 @@
 ;;   ,----
 ;;   | M-x bug-hunter-init-file RET i
 ;;   `----
 ;;   The Bug Hunter will start a separate Emacs frame several times, and
 ;;   then it will ask you each time whether that frame presented the
 ;;   problem you have. After doing this about 5--12 times, you’ll be given
 ;;   the results.
 ;;
@@ -98,7 +98,7 @@
 
 (defconst bug-hunter--interactive-explanation
   "You have asked to do an interactive hunt, here's how it goes.
-1) I will start a new Emacs frame.
+1) I will start a new Emacs instance, which opens a new frame.
 2) You will try to reproduce your problem on the new frame.
 3) When you’re done, close that frame.
 4) I will ask you if you managed to reproduce the problem.
@@ -280,7 +280,7 @@ ARGS are passed before \"-l FILE\"."
       (delete-file file-name))))
 
 (defun bug-hunter--run-form-interactively (form)
-  "Run FORM in a graphical frame and ask user about the outcome."
+  "Run FORM in a graphical instance and ask user about the outcome."
   (let ((file-name (bug-hunter--print-to-temp (list 'prin1 form))))
     (unwind-protect
         (bug-hunter--run-emacs file-name "-Q")
@@ -49,8 +49,8 @@
 ;;   | M-x bug-hunter-init-file RET i
 ;;   `----
-;;   The Bug Hunter will start a separate Emacs frame several times, and
-;;   then it will ask you each time whether that frame presented the
+;;   The Bug Hunter will start a separate Emacs instance several times, and
+;;   then it will ask you each time whether that instance presented the
 ;;   problem you have. After doing this about 5--12 times, you’ll be given
 ;;   the results.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]